///File : ItemSectionDBBase.hpp
//------------------------------------------------------------------------------
/*
    Copyright (C) 2009 Colin GILLE / congelli501

    This file is part of Devis Maker.
    Devis Maker is sold under Devis Maker license (read COPYING file)
*/
//------------------------------------------------------------------------------
#if not defined ITEM_ROOM_DB_BASE
#define ITEM_ROOM_DB_BASE
//------------------------------------------------------------------------------
#include <string>
#include <iostream>
#include <vector>
#include <map>
//------------------------------------------------------------------------------
#if not defined TIXML_USE_TICPP
    #define TIXML_USE_TICPP
#endif
#include "ticpp/ticpp.h"
#include "nbStrConvert.hpp"
//------------------------------------------------------------------------------
#include "config.hpp"
#include "buildVersionOptions.hpp"
//------------------------------------------------------------------------------

struct itemRef // Item DB
{
    std::string name;
    double taxe;
    double priceHT;
    double ecoPart;
};

class ItemSectionDBBase
{
public:
    // Init
    ItemSectionDBBase(const std::string &sectionDBPath, const std::string &itemDBPath);

    // Flags
    bool IsOk() const;
    bool IsModified() const;

    // Sections (general)
    bool SectionExists(const std::string &sectionID) const;
    int GetSectionPosInDB(const std::string &sectionID) const;
    std::vector<std::string> GetAllSectionsList() const;
    int GetAllSectionsCount() const;

    // Items (general)
    double GetItemPriceHT(const std::string &itemID) const;
    double GetItemTaxe(const std::string &itemID) const;
    double GetItemEcoPart(const std::string &itemID) const;
    std::string GetItemName(const std::string &itemID) const;
    bool ItemExists(const std::string &itemID) const;
    std::vector<std::string> GetAllItemsList() const;
    int GetAllItemsCount() const;

protected:
    // Init
    void InitSectionItemDB(const std::string &sectionDBPath, const std::string &itemDBPath);

    // DB
    void LoadSectionDB(const std::string &filename);
    void LoadItemDB(const std::string &filename);

    void SaveSectionDB(const std::string &filename);
    void SaveItemDB(const std::string &filename);

    // DB
    std::vector<std::string> m_sectionDB;
    std::map<std::string, itemRef> m_itemDB;

    // Flags
    bool m_isOk;
    bool m_isSectionsModified, m_isItemsModified;
};

#endif //ITEM_ROOM_DB_BASE
